# import secrets
import pytest
from rchain_grpc import repl


@pytest.fixture
def connection(rchain_host):
    return repl.create_connection(host=rchain_host)


@pytest.fixture
def contract_path():
    # file must be available from rchain container
    # look on `proof-monorepo/rchain` directory which is available
    # in rchain container on `/rchain` path.
    # It already has `test_contract.rho`
    return '/rchain/test_contract.rho'


@pytest.mark.xfail(reason='not work with current rnode')
def test_run(connection):
    ret = repl.run(connection, 'new x in { x!(1 + 1) }')
    assert isinstance(ret, dict)


@pytest.mark.xfail(reason='not work with current rnode')
def test_eval(connection, contract_path):
    ret = repl.eval(connection, contract_path)
    assert isinstance(ret, dict)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import CasperMessage_pb2 as CasperMessage__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class DeployServiceStub(object):
  """--------- DeployService  --------
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.DoDeploy = channel.unary_unary(
        '/coop.rchain.casper.protocol.DeployService/DoDeploy',
        request_serializer=CasperMessage__pb2.DeployData.SerializeToString,
        response_deserializer=CasperMessage__pb2.DeployServiceResponse.FromString,
        )
    self.addBlock = channel.unary_unary(
        '/coop.rchain.casper.protocol.DeployService/addBlock',
        request_serializer=CasperMessage__pb2.BlockMessage.SerializeToString,
        response_deserializer=CasperMessage__pb2.DeployServiceResponse.FromString,
        )
    self.createBlock = channel.unary_unary(
        '/coop.rchain.casper.protocol.DeployService/createBlock',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=CasperMessage__pb2.DeployServiceResponse.FromString,
        )
    self.showBlock = channel.unary_unary(
        '/coop.rchain.casper.protocol.DeployService/showBlock',
        request_serializer=CasperMessage__pb2.BlockQuery.SerializeToString,
        response_deserializer=CasperMessage__pb2.BlockQueryResponse.FromString,
        )
    self.showMainChain = channel.unary_stream(
        '/coop.rchain.casper.protocol.DeployService/showMainChain',
        request_serializer=CasperMessage__pb2.BlocksQuery.SerializeToString,
        response_deserializer=CasperMessage__pb2.BlockInfoWithoutTuplespace.FromString,
        )
    self.showBlocks = channel.unary_stream(
        '/coop.rchain.casper.protocol.DeployService/showBlocks',
        request_serializer=CasperMessage__pb2.BlocksQuery.SerializeToString,
        response_deserializer=CasperMessage__pb2.BlockInfoWithoutTuplespace.FromString,
        )
    self.listenForDataAtName = channel.unary_unary(
        '/coop.rchain.casper.protocol.DeployService/listenForDataAtName',
        request_serializer=CasperMessage__pb2.DataAtNameQuery.SerializeToString,
        response_deserializer=CasperMessage__pb2.ListeningNameDataResponse.FromString,
        )
    self.listenForContinuationAtName = channel.unary_unary(
        '/coop.rchain.casper.protocol.DeployService/listenForContinuationAtName',
        request_serializer=CasperMessage__pb2.ContinuationAtNameQuery.SerializeToString,
        response_deserializer=CasperMessage__pb2.ListeningNameContinuationResponse.FromString,
        )


class DeployServiceServicer(object):
  """--------- DeployService  --------
  """

  def DoDeploy(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def addBlock(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def createBlock(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def showBlock(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def showMainChain(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def showBlocks(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def listenForDataAtName(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def listenForContinuationAtName(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DeployServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'DoDeploy': grpc.unary_unary_rpc_method_handler(
          servicer.DoDeploy,
          request_deserializer=CasperMessage__pb2.DeployData.FromString,
          response_serializer=CasperMessage__pb2.DeployServiceResponse.SerializeToString,
      ),
      'addBlock': grpc.unary_unary_rpc_method_handler(
          servicer.addBlock,
          request_deserializer=CasperMessage__pb2.BlockMessage.FromString,
          response_serializer=CasperMessage__pb2.DeployServiceResponse.SerializeToString,
      ),
      'createBlock': grpc.unary_unary_rpc_method_handler(
          servicer.createBlock,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=CasperMessage__pb2.DeployServiceResponse.SerializeToString,
      ),
      'showBlock': grpc.unary_unary_rpc_method_handler(
          servicer.showBlock,
          request_deserializer=CasperMessage__pb2.BlockQuery.FromString,
          response_serializer=CasperMessage__pb2.BlockQueryResponse.SerializeToString,
      ),
      'showMainChain': grpc.unary_stream_rpc_method_handler(
          servicer.showMainChain,
          request_deserializer=CasperMessage__pb2.BlocksQuery.FromString,
          response_serializer=CasperMessage__pb2.BlockInfoWithoutTuplespace.SerializeToString,
      ),
      'showBlocks': grpc.unary_stream_rpc_method_handler(
          servicer.showBlocks,
          request_deserializer=CasperMessage__pb2.BlocksQuery.FromString,
          response_serializer=CasperMessage__pb2.BlockInfoWithoutTuplespace.SerializeToString,
      ),
      'listenForDataAtName': grpc.unary_unary_rpc_method_handler(
          servicer.listenForDataAtName,
          request_deserializer=CasperMessage__pb2.DataAtNameQuery.FromString,
          response_serializer=CasperMessage__pb2.ListeningNameDataResponse.SerializeToString,
      ),
      'listenForContinuationAtName': grpc.unary_unary_rpc_method_handler(
          servicer.listenForContinuationAtName,
          request_deserializer=CasperMessage__pb2.ContinuationAtNameQuery.FromString,
          response_serializer=CasperMessage__pb2.ListeningNameContinuationResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'coop.rchain.casper.protocol.DeployService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



import pytest
from click.testing import CliRunner

from rchain_grpc import cli


def test_command_line_interface():
    runner = CliRunner()
    result = runner.invoke(cli.main)
    assert result.exit_code == 0
    assert 'rchain_grpc.cli.main' in result.output
    help_result = runner.invoke(cli.main, ['--help'])
    assert help_result.exit_code == 0
    assert '--help  Show this message and exit.' in help_result.output



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: repl.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='repl.proto',
  package='coop.rchain.node.model',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\nrepl.proto\x12\x16\x63oop.rchain.node.model\"\x1a\n\nCmdRequest\x12\x0c\n\x04line\x18\x01 \x01(\t\"\x1e\n\x0b\x45valRequest\x12\x0f\n\x07program\x18\x01 \x01(\t\"\x1e\n\x0cReplResponse\x12\x0e\n\x06output\x18\x01 \x01(\t2\xae\x01\n\x04Repl\x12Q\n\x03Run\x12\".coop.rchain.node.model.CmdRequest\x1a$.coop.rchain.node.model.ReplResponse\"\x00\x12S\n\x04\x45val\x12#.coop.rchain.node.model.EvalRequest\x1a$.coop.rchain.node.model.ReplResponse\"\x00\x62\x06proto3')
)




_CMDREQUEST = _descriptor.Descriptor(
  name='CmdRequest',
  full_name='coop.rchain.node.model.CmdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='line', full_name='coop.rchain.node.model.CmdRequest.line', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=64,
)


_EVALREQUEST = _descriptor.Descriptor(
  name='EvalRequest',
  full_name='coop.rchain.node.model.EvalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='program', full_name='coop.rchain.node.model.EvalRequest.program', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=96,
)


_REPLRESPONSE = _descriptor.Descriptor(
  name='ReplResponse',
  full_name='coop.rchain.node.model.ReplResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output', full_name='coop.rchain.node.model.ReplResponse.output', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=128,
)

DESCRIPTOR.message_types_by_name['CmdRequest'] = _CMDREQUEST
DESCRIPTOR.message_types_by_name['EvalRequest'] = _EVALREQUEST
DESCRIPTOR.message_types_by_name['ReplResponse'] = _REPLRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CmdRequest = _reflection.GeneratedProtocolMessageType('CmdRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMDREQUEST,
  __module__ = 'repl_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.node.model.CmdRequest)
  ))
_sym_db.RegisterMessage(CmdRequest)

EvalRequest = _reflection.GeneratedProtocolMessageType('EvalRequest', (_message.Message,), dict(
  DESCRIPTOR = _EVALREQUEST,
  __module__ = 'repl_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.node.model.EvalRequest)
  ))
_sym_db.RegisterMessage(EvalRequest)

ReplResponse = _reflection.GeneratedProtocolMessageType('ReplResponse', (_message.Message,), dict(
  DESCRIPTOR = _REPLRESPONSE,
  __module__ = 'repl_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.node.model.ReplResponse)
  ))
_sym_db.RegisterMessage(ReplResponse)



_REPL = _descriptor.ServiceDescriptor(
  name='Repl',
  full_name='coop.rchain.node.model.Repl',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=131,
  serialized_end=305,
  methods=[
  _descriptor.MethodDescriptor(
    name='Run',
    full_name='coop.rchain.node.model.Repl.Run',
    index=0,
    containing_service=None,
    input_type=_CMDREQUEST,
    output_type=_REPLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Eval',
    full_name='coop.rchain.node.model.Repl.Eval',
    index=1,
    containing_service=None,
    input_type=_EVALREQUEST,
    output_type=_REPLRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_REPL)

DESCRIPTOR.services_by_name['Repl'] = _REPL

# @@protoc_insertion_point(module_scope)



from . import rho_types
from .generated import repl_pb2_grpc
from .generated.repl_pb2 import CmdRequest, EvalRequest
from .utils import Connection, create_connection_builder

create_connection = create_connection_builder(repl_pb2_grpc.ReplStub)


def run(connection: Connection, line: str) -> dict:
    """WARNING: not working:/"""
    cmd_request = rho_types.from_dict({'line': line}, CmdRequest)
    ret = connection.Run(cmd_request)
    return rho_types.to_dict(ret)


def eval(connection: Connection, program: str) -> dict:
    """WARNING: not working:/"""
    eval_request = rho_types.from_dict({'program': program}, EvalRequest)
    ret = connection.Eval(eval_request)
    return rho_types.to_dict(ret)




import json
import secrets
import time
from datetime import datetime
from typing import Any, Iterator, List, Optional

from google.protobuf.empty_pb2 import Empty

from . import rho_types
from .exceptions import CasperException, TimeoutException

from .generated.CasperMessage_pb2_grpc import DeployServiceStub
from .generated.CasperMessage_pb2 import (
    BlockQuery, BlocksQuery,
    PhloLimit, PhloPrice,
    DeployData,
)

from .utils import Connection, create_connection_builder, is_equal


def throw_if_not_successful(response: dict, name: str) -> dict:
    if response.get('success') is not True:
        raise CasperException(f'Operation "{name}": not successfull', response)
    return response


create_connection = create_connection_builder(DeployServiceStub)


def get_blocks(connection: Connection, depth: int = 1) -> List[dict]:
    """works in the same way as `./rnode show-blocks`"""
    output = connection.showBlocks(BlocksQuery(depth=depth))
    return [rho_types.to_dict(i) for i in output]


def get_block(connection: Connection, block_hash: str) -> dict:
    """works in the same way as `./rnode show-block HASH`"""
    output = connection.showBlock(
        BlockQuery(hash=block_hash)
    )
    return rho_types.to_dict(output).get('blockInfo')


def deploy(
    connection: Connection,
    term: str,
    from_: str = '0x0',
    phlo_limit: int = 10000000,
    phlo_price: int = 1,
    nonce: int = 0,
) -> dict:
    """works in the same way as `./rnode deploy`
    but expect contract code in `term` argument"""
    dt = datetime.now()
    timestamp = dt.microsecond
    deployData = rho_types.from_dict(
        {
            'term': term,
            'from': from_,
            'phloLimit': PhloLimit(value=phlo_limit),
            'phloPrice': PhloPrice(value=phlo_price),
            'nonce': nonce,
            'timestamp': timestamp,
        },
        DeployData,
    )

    output = connection.DoDeploy(deployData)
    return throw_if_not_successful(rho_types.to_dict(output), 'deploy')


def propose(connection: Connection) -> dict:
    """works in the same way as `./rnode propose`"""
    output = connection.createBlock(Empty())
    return throw_if_not_successful(rho_types.to_dict(output), 'propose')


def listen_on(
    connection: Connection, name: str, interval: float = 0.5, timeout: float = 60.0
) -> Iterator[dict]:
    ""
    """listen on channel and return iterator witch values.
    Check channel in every second given in `interval`"""
    old_value = {}

    # TODO: ask rchain dev team for making `showBlocks` streaming infinitely
    # TODO: use infinite stream from `showBlocks` instead and check only on new block
    start_time = time.time()
    while True:
        value = get_value_from(connection, name)
        if value is not None and not is_equal(value, old_value):
            yield value
            old_value = value
        if time.time() - start_time + interval > timeout:
            raise TimeoutException()
        time.sleep(interval)


def get_value_from(connection: Connection, name: str) -> Optional[dict]:
    """get value from channel on given name"""
    rchain_channel = rho_types.to_channel([name])
    output = connection.listenForDataAtName(rchain_channel)
    # from google.protobuf.json_format import MessageToDict
    # result = MessageToDict(output)
    # print(result)
    result = rho_types.to_dict(output)
    if 'blockResults' in result:
        return result
    return None


def run_and_get_value_from(
    connection: Connection,
    term: str,
    output_placeholder: str = 'proof_output',
    **deploy_kargs,
) -> dict:
    """function deploy and propose given term and if in term is used channel
    `proof_output` (eg. `proof_output!("hello")`") will listen on, replace this
    name with the internal channel and start listening on this. Name of this
    channel can be configured by `output_placeholder`. Rest of kargs will be
    passed to `deploy` function."""

    channel_name = f'rchain_grpc_{secrets.token_hex(5)}'
    channel_name_str = rho_types.to_public_channel_name(channel_name)
    preprocessed_term = term.replace(output_placeholder, channel_name_str)
    deploy(connection, preprocessed_term, **deploy_kargs)
    propose(connection)
    return get_value_from(connection, channel_name)


def run_contract(
    connection: Connection,
    contract_name: str,
    contract_args: List[Any],
    timeout: float = 60.0,
    **deploy_kwargs,
):
    """
    Run contract and return result if contract accept callback channel as last argument:
    ```rholang
    contract @"add1"(@number, cb) = {
      cb!(number + 1)
    }
    ```
    """
    ack_name = f'ack_{secrets.token_hex(10)}'
    ack_name_str = rho_types.to_public_channel_name(ack_name)
    contract_name_str = rho_types.to_public_channel_name(contract_name)
    contract_args_str = ', '.join(
        [json.dumps(a) for a in contract_args] + [f'*{ack_name_str}']
    )
    term = f'{contract_name_str}!({contract_args_str})'

    deploy(connection, term, **deploy_kwargs)
    propose(connection)
    return next(listen_on(connection, ack_name, timeout=timeout))



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import find_packages, setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

with open('requirements.txt') as f:
    requirements = f.read().splitlines()

setup_requirements = ['pytest-runner']

test_requirements = ['pytest']

setup(
    author="Mateusz Probachta",
    author_email='mateusz@proofmedia.io',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3 :: Only',
    ],
    description="python client to rchain gRPC",
    entry_points={'console_scripts': ['py_rchain_grpc=rchain_grpc.cli:main']},
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='rchain_grpc',
    name='rchain_grpc',
    packages=find_packages(include=['rchain_grpc']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/proof-media/rchain_grpc',
    version='0.7.0',
    zip_safe=True,
)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CasperMessage.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
import RhoTypes_pb2 as RhoTypes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='CasperMessage.proto',
  package='coop.rchain.casper.protocol',
  syntax='proto3',
  serialized_options=_b('\342?\037\n\033coop.rchain.casper.protocol\020\001'),
  serialized_pb=_b('\n\x13\x43\x61sperMessage.proto\x12\x1b\x63oop.rchain.casper.protocol\x1a\x1bgoogle/protobuf/empty.proto\x1a\x15scalapb/scalapb.proto\x1a\x0eRhoTypes.proto\"\x1a\n\tPhloLimit\x12\r\n\x05value\x18\x01 \x01(\x03\"\x1a\n\tPhloPrice\x12\r\n\x05value\x18\x01 \x01(\x03\"\xf1\x01\n\nDeployData\x12\x0c\n\x04user\x18\x01 \x01(\x0c\x12\x0c\n\x04term\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x0b\n\x03sig\x18\x04 \x01(\x0c\x12\x14\n\x0csigAlgorithm\x18\x05 \x01(\t\x12\x0c\n\x04\x66rom\x18\x06 \x01(\t\x12\x39\n\tphloPrice\x18\x07 \x01(\x0b\x32&.coop.rchain.casper.protocol.PhloPrice\x12\x39\n\tphloLimit\x18\x08 \x01(\x0b\x32&.coop.rchain.casper.protocol.PhloLimit\x12\r\n\x05nonce\x18\t \x01(\x05\"0\n\x0c\x42lockRequest\x12\x12\n\nbase16Hash\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\"\x1a\n\nBlockQuery\x12\x0c\n\x04hash\x18\x01 \x01(\t\"\x1c\n\x0b\x42locksQuery\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\"4\n\x0f\x44\x61taAtNameQuery\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\x12\x12\n\x04name\x18\x02 \x01(\x0b\x32\x04.Par\"=\n\x17\x43ontinuationAtNameQuery\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\x12\x13\n\x05names\x18\x02 \x03(\x0b\x32\x04.Par\"9\n\x15\x44\x65ployServiceResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"M\n\x11MaybeBlockMessage\x12\x38\n\x05\x62lock\x18\x01 \x01(\x0b\x32).coop.rchain.casper.protocol.BlockMessage\"_\n\x12\x42lockQueryResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x39\n\tblockInfo\x18\x02 \x01(\x0b\x32&.coop.rchain.casper.protocol.BlockInfo\"\x81\x01\n\x19ListeningNameDataResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x44\n\x0c\x62lockResults\x18\x02 \x03(\x0b\x32..coop.rchain.casper.protocol.DataWithBlockInfo\x12\x0e\n\x06length\x18\x03 \x01(\x05\"\x92\x01\n!ListeningNameContinuationResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12M\n\x0c\x62lockResults\x18\x02 \x03(\x0b\x32\x37.coop.rchain.casper.protocol.ContinuationsWithBlockInfo\x12\x0e\n\x06length\x18\x03 \x01(\x05\"x\n\x11\x44\x61taWithBlockInfo\x12\x1b\n\rpostBlockData\x18\x01 \x03(\x0b\x32\x04.Par\x12\x46\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x37.coop.rchain.casper.protocol.BlockInfoWithoutTuplespace\"\xba\x01\n\x1a\x43ontinuationsWithBlockInfo\x12T\n\x16postBlockContinuations\x18\x01 \x03(\x0b\x32\x34.coop.rchain.casper.protocol.WaitingContinuationInfo\x12\x46\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x37.coop.rchain.casper.protocol.BlockInfoWithoutTuplespace\"g\n\x17WaitingContinuationInfo\x12\'\n\x11postBlockPatterns\x18\x01 \x03(\x0b\x32\x0c.BindPattern\x12#\n\x15postBlockContinuation\x18\x02 \x01(\x0b\x32\x04.Par\"\x81\x02\n\x1a\x42lockInfoWithoutTuplespace\x12\x11\n\tblockHash\x18\x01 \x01(\t\x12\x11\n\tblockSize\x18\x02 \x01(\t\x12\x13\n\x0b\x62lockNumber\x18\x03 \x01(\x03\x12\x0f\n\x07version\x18\x04 \x01(\x03\x12\x13\n\x0b\x64\x65ployCount\x18\x05 \x01(\x05\x12\x16\n\x0etupleSpaceHash\x18\x06 \x01(\t\x12\x11\n\ttimestamp\x18\x07 \x01(\x03\x12\x16\n\x0e\x66\x61ultTolerance\x18\x08 \x01(\x02\x12\x16\n\x0emainParentHash\x18\t \x01(\t\x12\x17\n\x0fparentsHashList\x18\n \x03(\t\x12\x0e\n\x06sender\x18\x0b \x01(\t\"\x99\x02\n\tBlockInfo\x12\x11\n\tblockHash\x18\x01 \x01(\t\x12\x11\n\tblockSize\x18\x02 \x01(\t\x12\x13\n\x0b\x62lockNumber\x18\x03 \x01(\x03\x12\x0f\n\x07version\x18\x04 \x01(\x03\x12\x13\n\x0b\x64\x65ployCount\x18\x05 \x01(\x05\x12\x16\n\x0etupleSpaceHash\x18\x06 \x01(\t\x12\x16\n\x0etupleSpaceDump\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\x03\x12\x16\n\x0e\x66\x61ultTolerance\x18\t \x01(\x02\x12\x16\n\x0emainParentHash\x18\n \x01(\t\x12\x17\n\x0fparentsHashList\x18\x0b \x03(\t\x12\x0e\n\x06sender\x18\x0c \x01(\t\x12\x0f\n\x07shardId\x18\r \x01(\t\"h\n\x16\x41pprovedBlockCandidate\x12\x38\n\x05\x62lock\x18\x01 \x01(\x0b\x32).coop.rchain.casper.protocol.BlockMessage\x12\x14\n\x0crequiredSigs\x18\x02 \x01(\x05\"~\n\x0fUnapprovedBlock\x12\x46\n\tcandidate\x18\x01 \x01(\x0b\x32\x33.coop.rchain.casper.protocol.ApprovedBlockCandidate\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\">\n\tSignature\x12\x11\n\tpublicKey\x18\x01 \x01(\x0c\x12\x11\n\talgorithm\x18\x02 \x01(\t\x12\x0b\n\x03sig\x18\x03 \x01(\x0c\"\x8c\x01\n\rBlockApproval\x12\x46\n\tcandidate\x18\x01 \x01(\x0b\x32\x33.coop.rchain.casper.protocol.ApprovedBlockCandidate\x12\x33\n\x03sig\x18\x02 \x01(\x0b\x32&.coop.rchain.casper.protocol.Signature\"\x8d\x01\n\rApprovedBlock\x12\x46\n\tcandidate\x18\x01 \x01(\x0b\x32\x33.coop.rchain.casper.protocol.ApprovedBlockCandidate\x12\x34\n\x04sigs\x18\x02 \x03(\x0b\x32&.coop.rchain.casper.protocol.Signature\"*\n\x14\x41pprovedBlockRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\"E\n\x18NoApprovedBlockAvailable\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x15\n\rnodeIdentifer\x18\x02 \x01(\t\"\xb3\x02\n\x0c\x42lockMessage\x12\x11\n\tblockHash\x18\x01 \x01(\x0c\x12\x33\n\x06header\x18\x02 \x01(\x0b\x32#.coop.rchain.casper.protocol.Header\x12/\n\x04\x62ody\x18\x03 \x01(\x0b\x32!.coop.rchain.casper.protocol.Body\x12\x42\n\x0ejustifications\x18\x04 \x03(\x0b\x32*.coop.rchain.casper.protocol.Justification\x12\x0e\n\x06sender\x18\x05 \x01(\x0c\x12\x0e\n\x06seqNum\x18\x06 \x01(\x05\x12\x0b\n\x03sig\x18\x07 \x01(\x0c\x12\x14\n\x0csigAlgorithm\x18\x08 \x01(\t\x12\x0f\n\x07shardId\x18\t \x01(\t\x12\x12\n\nextraBytes\x18\n \x01(\x0c\"\x9a\x01\n\x06Header\x12\x17\n\x0fparentsHashList\x18\x01 \x03(\x0c\x12\x15\n\rpostStateHash\x18\x02 \x01(\x0c\x12\x13\n\x0b\x64\x65ploysHash\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\x12\x0f\n\x07version\x18\x06 \x01(\x03\x12\x13\n\x0b\x64\x65ployCount\x18\x07 \x01(\x05\x12\x12\n\nextraBytes\x18\x08 \x01(\x0c\"\x9e\x01\n\x0fProcessedDeploy\x12\x33\n\x06\x64\x65ploy\x18\x01 \x01(\x0b\x32#.coop.rchain.casper.protocol.Deploy\x12\x14\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x06.PCost\x12/\n\x03log\x18\x03 \x03(\x0b\x32\".coop.rchain.casper.protocol.Event\x12\x0f\n\x07\x65rrored\x18\x04 \x01(\x08\"\x96\x01\n\x04\x42ody\x12;\n\tpostState\x18\x01 \x01(\x0b\x32(.coop.rchain.casper.protocol.RChainState\x12=\n\x07\x64\x65ploys\x18\x02 \x03(\x0b\x32,.coop.rchain.casper.protocol.ProcessedDeploy\x12\x12\n\nextraBytes\x18\x03 \x01(\x0c\";\n\rJustification\x12\x11\n\tvalidator\x18\x01 \x01(\x0c\x12\x17\n\x0flatestBlockHash\x18\x02 \x01(\x0c\"h\n\x0bRChainState\x12\x12\n\ntuplespace\x18\x01 \x01(\x0c\x12\x30\n\x05\x62onds\x18\x02 \x03(\x0b\x32!.coop.rchain.casper.protocol.Bond\x12\x13\n\x0b\x62lockNumber\x18\x03 \x01(\x03\"R\n\x06\x44\x65ploy\x12\x12\n\x04term\x18\x01 \x01(\x0b\x32\x04.Par\x12\x34\n\x03raw\x18\x02 \x01(\x0b\x32\'.coop.rchain.casper.protocol.DeployData\"\xcd\x01\n\x05\x45vent\x12<\n\x07produce\x18\x01 \x01(\x0b\x32).coop.rchain.casper.protocol.ProduceEventH\x00\x12<\n\x07\x63onsume\x18\x02 \x01(\x0b\x32).coop.rchain.casper.protocol.ConsumeEventH\x00\x12\x36\n\x04\x63omm\x18\x03 \x01(\x0b\x32&.coop.rchain.casper.protocol.CommEventH\x00\x42\x10\n\x0e\x65vent_instance\"2\n\x0cProduceEvent\x12\x14\n\x0c\x63hannelsHash\x18\x01 \x01(\x0c\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\"2\n\x0c\x43onsumeEvent\x12\x14\n\x0c\x63hannelsHash\x18\x01 \x01(\x0c\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\"\x84\x01\n\tCommEvent\x12:\n\x07\x63onsume\x18\x01 \x01(\x0b\x32).coop.rchain.casper.protocol.ConsumeEvent\x12;\n\x08produces\x18\x02 \x03(\x0b\x32).coop.rchain.casper.protocol.ProduceEvent\"(\n\x04\x42ond\x12\x11\n\tvalidator\x18\x01 \x01(\x0c\x12\r\n\x05stake\x18\x02 \x01(\x03\x32\xb1\x07\n\rDeployService\x12i\n\x08\x44oDeploy\x12\'.coop.rchain.casper.protocol.DeployData\x1a\x32.coop.rchain.casper.protocol.DeployServiceResponse\"\x00\x12k\n\x08\x61\x64\x64\x42lock\x12).coop.rchain.casper.protocol.BlockMessage\x1a\x32.coop.rchain.casper.protocol.DeployServiceResponse\"\x00\x12[\n\x0b\x63reateBlock\x12\x16.google.protobuf.Empty\x1a\x32.coop.rchain.casper.protocol.DeployServiceResponse\"\x00\x12g\n\tshowBlock\x12\'.coop.rchain.casper.protocol.BlockQuery\x1a/.coop.rchain.casper.protocol.BlockQueryResponse\"\x00\x12v\n\rshowMainChain\x12(.coop.rchain.casper.protocol.BlocksQuery\x1a\x37.coop.rchain.casper.protocol.BlockInfoWithoutTuplespace\"\x00\x30\x01\x12s\n\nshowBlocks\x12(.coop.rchain.casper.protocol.BlocksQuery\x1a\x37.coop.rchain.casper.protocol.BlockInfoWithoutTuplespace\"\x00\x30\x01\x12}\n\x13listenForDataAtName\x12,.coop.rchain.casper.protocol.DataAtNameQuery\x1a\x36.coop.rchain.casper.protocol.ListeningNameDataResponse\"\x00\x12\x95\x01\n\x1blistenForContinuationAtName\x12\x34.coop.rchain.casper.protocol.ContinuationAtNameQuery\x1a>.coop.rchain.casper.protocol.ListeningNameContinuationResponse\"\x00\x42\"\xe2?\x1f\n\x1b\x63oop.rchain.casper.protocol\x10\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,RhoTypes__pb2.DESCRIPTOR,])




_PHLOLIMIT = _descriptor.Descriptor(
  name='PhloLimit',
  full_name='coop.rchain.casper.protocol.PhloLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='coop.rchain.casper.protocol.PhloLimit.value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=146,
)


_PHLOPRICE = _descriptor.Descriptor(
  name='PhloPrice',
  full_name='coop.rchain.casper.protocol.PhloPrice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='coop.rchain.casper.protocol.PhloPrice.value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=174,
)


_DEPLOYDATA = _descriptor.Descriptor(
  name='DeployData',
  full_name='coop.rchain.casper.protocol.DeployData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='coop.rchain.casper.protocol.DeployData.user', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='term', full_name='coop.rchain.casper.protocol.DeployData.term', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='coop.rchain.casper.protocol.DeployData.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sig', full_name='coop.rchain.casper.protocol.DeployData.sig', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sigAlgorithm', full_name='coop.rchain.casper.protocol.DeployData.sigAlgorithm', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from', full_name='coop.rchain.casper.protocol.DeployData.from', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phloPrice', full_name='coop.rchain.casper.protocol.DeployData.phloPrice', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phloLimit', full_name='coop.rchain.casper.protocol.DeployData.phloLimit', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='coop.rchain.casper.protocol.DeployData.nonce', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=418,
)


_BLOCKREQUEST = _descriptor.Descriptor(
  name='BlockRequest',
  full_name='coop.rchain.casper.protocol.BlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base16Hash', full_name='coop.rchain.casper.protocol.BlockRequest.base16Hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='coop.rchain.casper.protocol.BlockRequest.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=468,
)


_BLOCKQUERY = _descriptor.Descriptor(
  name='BlockQuery',
  full_name='coop.rchain.casper.protocol.BlockQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='coop.rchain.casper.protocol.BlockQuery.hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=496,
)


_BLOCKSQUERY = _descriptor.Descriptor(
  name='BlocksQuery',
  full_name='coop.rchain.casper.protocol.BlocksQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='coop.rchain.casper.protocol.BlocksQuery.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=498,
  serialized_end=526,
)


_DATAATNAMEQUERY = _descriptor.Descriptor(
  name='DataAtNameQuery',
  full_name='coop.rchain.casper.protocol.DataAtNameQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='coop.rchain.casper.protocol.DataAtNameQuery.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='coop.rchain.casper.protocol.DataAtNameQuery.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=580,
)


_CONTINUATIONATNAMEQUERY = _descriptor.Descriptor(
  name='ContinuationAtNameQuery',
  full_name='coop.rchain.casper.protocol.ContinuationAtNameQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='coop.rchain.casper.protocol.ContinuationAtNameQuery.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='names', full_name='coop.rchain.casper.protocol.ContinuationAtNameQuery.names', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=643,
)


_DEPLOYSERVICERESPONSE = _descriptor.Descriptor(
  name='DeployServiceResponse',
  full_name='coop.rchain.casper.protocol.DeployServiceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='coop.rchain.casper.protocol.DeployServiceResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='coop.rchain.casper.protocol.DeployServiceResponse.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=645,
  serialized_end=702,
)


_MAYBEBLOCKMESSAGE = _descriptor.Descriptor(
  name='MaybeBlockMessage',
  full_name='coop.rchain.casper.protocol.MaybeBlockMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='coop.rchain.casper.protocol.MaybeBlockMessage.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=781,
)


_BLOCKQUERYRESPONSE = _descriptor.Descriptor(
  name='BlockQueryResponse',
  full_name='coop.rchain.casper.protocol.BlockQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='coop.rchain.casper.protocol.BlockQueryResponse.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='coop.rchain.casper.protocol.BlockQueryResponse.blockInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=783,
  serialized_end=878,
)


_LISTENINGNAMEDATARESPONSE = _descriptor.Descriptor(
  name='ListeningNameDataResponse',
  full_name='coop.rchain.casper.protocol.ListeningNameDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='coop.rchain.casper.protocol.ListeningNameDataResponse.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockResults', full_name='coop.rchain.casper.protocol.ListeningNameDataResponse.blockResults', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='coop.rchain.casper.protocol.ListeningNameDataResponse.length', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=881,
  serialized_end=1010,
)


_LISTENINGNAMECONTINUATIONRESPONSE = _descriptor.Descriptor(
  name='ListeningNameContinuationResponse',
  full_name='coop.rchain.casper.protocol.ListeningNameContinuationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='coop.rchain.casper.protocol.ListeningNameContinuationResponse.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockResults', full_name='coop.rchain.casper.protocol.ListeningNameContinuationResponse.blockResults', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='coop.rchain.casper.protocol.ListeningNameContinuationResponse.length', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1013,
  serialized_end=1159,
)


_DATAWITHBLOCKINFO = _descriptor.Descriptor(
  name='DataWithBlockInfo',
  full_name='coop.rchain.casper.protocol.DataWithBlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='postBlockData', full_name='coop.rchain.casper.protocol.DataWithBlockInfo.postBlockData', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='coop.rchain.casper.protocol.DataWithBlockInfo.block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1161,
  serialized_end=1281,
)


_CONTINUATIONSWITHBLOCKINFO = _descriptor.Descriptor(
  name='ContinuationsWithBlockInfo',
  full_name='coop.rchain.casper.protocol.ContinuationsWithBlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='postBlockContinuations', full_name='coop.rchain.casper.protocol.ContinuationsWithBlockInfo.postBlockContinuations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='coop.rchain.casper.protocol.ContinuationsWithBlockInfo.block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1284,
  serialized_end=1470,
)


_WAITINGCONTINUATIONINFO = _descriptor.Descriptor(
  name='WaitingContinuationInfo',
  full_name='coop.rchain.casper.protocol.WaitingContinuationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='postBlockPatterns', full_name='coop.rchain.casper.protocol.WaitingContinuationInfo.postBlockPatterns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postBlockContinuation', full_name='coop.rchain.casper.protocol.WaitingContinuationInfo.postBlockContinuation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1472,
  serialized_end=1575,
)


_BLOCKINFOWITHOUTTUPLESPACE = _descriptor.Descriptor(
  name='BlockInfoWithoutTuplespace',
  full_name='coop.rchain.casper.protocol.BlockInfoWithoutTuplespace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockHash', full_name='coop.rchain.casper.protocol.BlockInfoWithoutTuplespace.blockHash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockSize', full_name='coop.rchain.casper.protocol.BlockInfoWithoutTuplespace.blockSize', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockNumber', full_name='coop.rchain.casper.protocol.BlockInfoWithoutTuplespace.blockNumber', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='coop.rchain.casper.protocol.BlockInfoWithoutTuplespace.version', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deployCount', full_name='coop.rchain.casper.protocol.BlockInfoWithoutTuplespace.deployCount', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tupleSpaceHash', full_name='coop.rchain.casper.protocol.BlockInfoWithoutTuplespace.tupleSpaceHash', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='coop.rchain.casper.protocol.BlockInfoWithoutTuplespace.timestamp', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='faultTolerance', full_name='coop.rchain.casper.protocol.BlockInfoWithoutTuplespace.faultTolerance', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mainParentHash', full_name='coop.rchain.casper.protocol.BlockInfoWithoutTuplespace.mainParentHash', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parentsHashList', full_name='coop.rchain.casper.protocol.BlockInfoWithoutTuplespace.parentsHashList', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender', full_name='coop.rchain.casper.protocol.BlockInfoWithoutTuplespace.sender', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1578,
  serialized_end=1835,
)


_BLOCKINFO = _descriptor.Descriptor(
  name='BlockInfo',
  full_name='coop.rchain.casper.protocol.BlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockHash', full_name='coop.rchain.casper.protocol.BlockInfo.blockHash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockSize', full_name='coop.rchain.casper.protocol.BlockInfo.blockSize', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockNumber', full_name='coop.rchain.casper.protocol.BlockInfo.blockNumber', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='coop.rchain.casper.protocol.BlockInfo.version', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deployCount', full_name='coop.rchain.casper.protocol.BlockInfo.deployCount', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tupleSpaceHash', full_name='coop.rchain.casper.protocol.BlockInfo.tupleSpaceHash', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tupleSpaceDump', full_name='coop.rchain.casper.protocol.BlockInfo.tupleSpaceDump', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='coop.rchain.casper.protocol.BlockInfo.timestamp', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='faultTolerance', full_name='coop.rchain.casper.protocol.BlockInfo.faultTolerance', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mainParentHash', full_name='coop.rchain.casper.protocol.BlockInfo.mainParentHash', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parentsHashList', full_name='coop.rchain.casper.protocol.BlockInfo.parentsHashList', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender', full_name='coop.rchain.casper.protocol.BlockInfo.sender', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shardId', full_name='coop.rchain.casper.protocol.BlockInfo.shardId', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1838,
  serialized_end=2119,
)


_APPROVEDBLOCKCANDIDATE = _descriptor.Descriptor(
  name='ApprovedBlockCandidate',
  full_name='coop.rchain.casper.protocol.ApprovedBlockCandidate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='coop.rchain.casper.protocol.ApprovedBlockCandidate.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requiredSigs', full_name='coop.rchain.casper.protocol.ApprovedBlockCandidate.requiredSigs', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2121,
  serialized_end=2225,
)


_UNAPPROVEDBLOCK = _descriptor.Descriptor(
  name='UnapprovedBlock',
  full_name='coop.rchain.casper.protocol.UnapprovedBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='candidate', full_name='coop.rchain.casper.protocol.UnapprovedBlock.candidate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='coop.rchain.casper.protocol.UnapprovedBlock.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='coop.rchain.casper.protocol.UnapprovedBlock.duration', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2227,
  serialized_end=2353,
)


_SIGNATURE = _descriptor.Descriptor(
  name='Signature',
  full_name='coop.rchain.casper.protocol.Signature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='publicKey', full_name='coop.rchain.casper.protocol.Signature.publicKey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='coop.rchain.casper.protocol.Signature.algorithm', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sig', full_name='coop.rchain.casper.protocol.Signature.sig', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2355,
  serialized_end=2417,
)


_BLOCKAPPROVAL = _descriptor.Descriptor(
  name='BlockApproval',
  full_name='coop.rchain.casper.protocol.BlockApproval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='candidate', full_name='coop.rchain.casper.protocol.BlockApproval.candidate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sig', full_name='coop.rchain.casper.protocol.BlockApproval.sig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2420,
  serialized_end=2560,
)


_APPROVEDBLOCK = _descriptor.Descriptor(
  name='ApprovedBlock',
  full_name='coop.rchain.casper.protocol.ApprovedBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='candidate', full_name='coop.rchain.casper.protocol.ApprovedBlock.candidate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sigs', full_name='coop.rchain.casper.protocol.ApprovedBlock.sigs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2563,
  serialized_end=2704,
)


_APPROVEDBLOCKREQUEST = _descriptor.Descriptor(
  name='ApprovedBlockRequest',
  full_name='coop.rchain.casper.protocol.ApprovedBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coop.rchain.casper.protocol.ApprovedBlockRequest.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2706,
  serialized_end=2748,
)


_NOAPPROVEDBLOCKAVAILABLE = _descriptor.Descriptor(
  name='NoApprovedBlockAvailable',
  full_name='coop.rchain.casper.protocol.NoApprovedBlockAvailable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coop.rchain.casper.protocol.NoApprovedBlockAvailable.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nodeIdentifer', full_name='coop.rchain.casper.protocol.NoApprovedBlockAvailable.nodeIdentifer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2750,
  serialized_end=2819,
)


_BLOCKMESSAGE = _descriptor.Descriptor(
  name='BlockMessage',
  full_name='coop.rchain.casper.protocol.BlockMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockHash', full_name='coop.rchain.casper.protocol.BlockMessage.blockHash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header', full_name='coop.rchain.casper.protocol.BlockMessage.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='coop.rchain.casper.protocol.BlockMessage.body', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='justifications', full_name='coop.rchain.casper.protocol.BlockMessage.justifications', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender', full_name='coop.rchain.casper.protocol.BlockMessage.sender', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNum', full_name='coop.rchain.casper.protocol.BlockMessage.seqNum', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sig', full_name='coop.rchain.casper.protocol.BlockMessage.sig', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sigAlgorithm', full_name='coop.rchain.casper.protocol.BlockMessage.sigAlgorithm', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shardId', full_name='coop.rchain.casper.protocol.BlockMessage.shardId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extraBytes', full_name='coop.rchain.casper.protocol.BlockMessage.extraBytes', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2822,
  serialized_end=3129,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='coop.rchain.casper.protocol.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parentsHashList', full_name='coop.rchain.casper.protocol.Header.parentsHashList', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postStateHash', full_name='coop.rchain.casper.protocol.Header.postStateHash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploysHash', full_name='coop.rchain.casper.protocol.Header.deploysHash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='coop.rchain.casper.protocol.Header.timestamp', index=3,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='coop.rchain.casper.protocol.Header.version', index=4,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deployCount', full_name='coop.rchain.casper.protocol.Header.deployCount', index=5,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extraBytes', full_name='coop.rchain.casper.protocol.Header.extraBytes', index=6,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3132,
  serialized_end=3286,
)


_PROCESSEDDEPLOY = _descriptor.Descriptor(
  name='ProcessedDeploy',
  full_name='coop.rchain.casper.protocol.ProcessedDeploy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy', full_name='coop.rchain.casper.protocol.ProcessedDeploy.deploy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost', full_name='coop.rchain.casper.protocol.ProcessedDeploy.cost', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log', full_name='coop.rchain.casper.protocol.ProcessedDeploy.log', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errored', full_name='coop.rchain.casper.protocol.ProcessedDeploy.errored', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3289,
  serialized_end=3447,
)


_BODY = _descriptor.Descriptor(
  name='Body',
  full_name='coop.rchain.casper.protocol.Body',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='postState', full_name='coop.rchain.casper.protocol.Body.postState', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploys', full_name='coop.rchain.casper.protocol.Body.deploys', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extraBytes', full_name='coop.rchain.casper.protocol.Body.extraBytes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3450,
  serialized_end=3600,
)


_JUSTIFICATION = _descriptor.Descriptor(
  name='Justification',
  full_name='coop.rchain.casper.protocol.Justification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='coop.rchain.casper.protocol.Justification.validator', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latestBlockHash', full_name='coop.rchain.casper.protocol.Justification.latestBlockHash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3602,
  serialized_end=3661,
)


_RCHAINSTATE = _descriptor.Descriptor(
  name='RChainState',
  full_name='coop.rchain.casper.protocol.RChainState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tuplespace', full_name='coop.rchain.casper.protocol.RChainState.tuplespace', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bonds', full_name='coop.rchain.casper.protocol.RChainState.bonds', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockNumber', full_name='coop.rchain.casper.protocol.RChainState.blockNumber', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3663,
  serialized_end=3767,
)


_DEPLOY = _descriptor.Descriptor(
  name='Deploy',
  full_name='coop.rchain.casper.protocol.Deploy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='term', full_name='coop.rchain.casper.protocol.Deploy.term', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw', full_name='coop.rchain.casper.protocol.Deploy.raw', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3769,
  serialized_end=3851,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='coop.rchain.casper.protocol.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='produce', full_name='coop.rchain.casper.protocol.Event.produce', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consume', full_name='coop.rchain.casper.protocol.Event.consume', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comm', full_name='coop.rchain.casper.protocol.Event.comm', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event_instance', full_name='coop.rchain.casper.protocol.Event.event_instance',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3854,
  serialized_end=4059,
)


_PRODUCEEVENT = _descriptor.Descriptor(
  name='ProduceEvent',
  full_name='coop.rchain.casper.protocol.ProduceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channelsHash', full_name='coop.rchain.casper.protocol.ProduceEvent.channelsHash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='coop.rchain.casper.protocol.ProduceEvent.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4061,
  serialized_end=4111,
)


_CONSUMEEVENT = _descriptor.Descriptor(
  name='ConsumeEvent',
  full_name='coop.rchain.casper.protocol.ConsumeEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channelsHash', full_name='coop.rchain.casper.protocol.ConsumeEvent.channelsHash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='coop.rchain.casper.protocol.ConsumeEvent.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4113,
  serialized_end=4163,
)


_COMMEVENT = _descriptor.Descriptor(
  name='CommEvent',
  full_name='coop.rchain.casper.protocol.CommEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='consume', full_name='coop.rchain.casper.protocol.CommEvent.consume', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='produces', full_name='coop.rchain.casper.protocol.CommEvent.produces', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4166,
  serialized_end=4298,
)


_BOND = _descriptor.Descriptor(
  name='Bond',
  full_name='coop.rchain.casper.protocol.Bond',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='coop.rchain.casper.protocol.Bond.validator', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stake', full_name='coop.rchain.casper.protocol.Bond.stake', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4300,
  serialized_end=4340,
)

_DEPLOYDATA.fields_by_name['phloPrice'].message_type = _PHLOPRICE
_DEPLOYDATA.fields_by_name['phloLimit'].message_type = _PHLOLIMIT
_DATAATNAMEQUERY.fields_by_name['name'].message_type = RhoTypes__pb2._PAR
_CONTINUATIONATNAMEQUERY.fields_by_name['names'].message_type = RhoTypes__pb2._PAR
_MAYBEBLOCKMESSAGE.fields_by_name['block'].message_type = _BLOCKMESSAGE
_BLOCKQUERYRESPONSE.fields_by_name['blockInfo'].message_type = _BLOCKINFO
_LISTENINGNAMEDATARESPONSE.fields_by_name['blockResults'].message_type = _DATAWITHBLOCKINFO
_LISTENINGNAMECONTINUATIONRESPONSE.fields_by_name['blockResults'].message_type = _CONTINUATIONSWITHBLOCKINFO
_DATAWITHBLOCKINFO.fields_by_name['postBlockData'].message_type = RhoTypes__pb2._PAR
_DATAWITHBLOCKINFO.fields_by_name['block'].message_type = _BLOCKINFOWITHOUTTUPLESPACE
_CONTINUATIONSWITHBLOCKINFO.fields_by_name['postBlockContinuations'].message_type = _WAITINGCONTINUATIONINFO
_CONTINUATIONSWITHBLOCKINFO.fields_by_name['block'].message_type = _BLOCKINFOWITHOUTTUPLESPACE
_WAITINGCONTINUATIONINFO.fields_by_name['postBlockPatterns'].message_type = RhoTypes__pb2._BINDPATTERN
_WAITINGCONTINUATIONINFO.fields_by_name['postBlockContinuation'].message_type = RhoTypes__pb2._PAR
_APPROVEDBLOCKCANDIDATE.fields_by_name['block'].message_type = _BLOCKMESSAGE
_UNAPPROVEDBLOCK.fields_by_name['candidate'].message_type = _APPROVEDBLOCKCANDIDATE
_BLOCKAPPROVAL.fields_by_name['candidate'].message_type = _APPROVEDBLOCKCANDIDATE
_BLOCKAPPROVAL.fields_by_name['sig'].message_type = _SIGNATURE
_APPROVEDBLOCK.fields_by_name['candidate'].message_type = _APPROVEDBLOCKCANDIDATE
_APPROVEDBLOCK.fields_by_name['sigs'].message_type = _SIGNATURE
_BLOCKMESSAGE.fields_by_name['header'].message_type = _HEADER
_BLOCKMESSAGE.fields_by_name['body'].message_type = _BODY
_BLOCKMESSAGE.fields_by_name['justifications'].message_type = _JUSTIFICATION
_PROCESSEDDEPLOY.fields_by_name['deploy'].message_type = _DEPLOY
_PROCESSEDDEPLOY.fields_by_name['cost'].message_type = RhoTypes__pb2._PCOST
_PROCESSEDDEPLOY.fields_by_name['log'].message_type = _EVENT
_BODY.fields_by_name['postState'].message_type = _RCHAINSTATE
_BODY.fields_by_name['deploys'].message_type = _PROCESSEDDEPLOY
_RCHAINSTATE.fields_by_name['bonds'].message_type = _BOND
_DEPLOY.fields_by_name['term'].message_type = RhoTypes__pb2._PAR
_DEPLOY.fields_by_name['raw'].message_type = _DEPLOYDATA
_EVENT.fields_by_name['produce'].message_type = _PRODUCEEVENT
_EVENT.fields_by_name['consume'].message_type = _CONSUMEEVENT
_EVENT.fields_by_name['comm'].message_type = _COMMEVENT
_EVENT.oneofs_by_name['event_instance'].fields.append(
  _EVENT.fields_by_name['produce'])
_EVENT.fields_by_name['produce'].containing_oneof = _EVENT.oneofs_by_name['event_instance']
_EVENT.oneofs_by_name['event_instance'].fields.append(
  _EVENT.fields_by_name['consume'])
_EVENT.fields_by_name['consume'].containing_oneof = _EVENT.oneofs_by_name['event_instance']
_EVENT.oneofs_by_name['event_instance'].fields.append(
  _EVENT.fields_by_name['comm'])
_EVENT.fields_by_name['comm'].containing_oneof = _EVENT.oneofs_by_name['event_instance']
_COMMEVENT.fields_by_name['consume'].message_type = _CONSUMEEVENT
_COMMEVENT.fields_by_name['produces'].message_type = _PRODUCEEVENT
DESCRIPTOR.message_types_by_name['PhloLimit'] = _PHLOLIMIT
DESCRIPTOR.message_types_by_name['PhloPrice'] = _PHLOPRICE
DESCRIPTOR.message_types_by_name['DeployData'] = _DEPLOYDATA
DESCRIPTOR.message_types_by_name['BlockRequest'] = _BLOCKREQUEST
DESCRIPTOR.message_types_by_name['BlockQuery'] = _BLOCKQUERY
DESCRIPTOR.message_types_by_name['BlocksQuery'] = _BLOCKSQUERY
DESCRIPTOR.message_types_by_name['DataAtNameQuery'] = _DATAATNAMEQUERY
DESCRIPTOR.message_types_by_name['ContinuationAtNameQuery'] = _CONTINUATIONATNAMEQUERY
DESCRIPTOR.message_types_by_name['DeployServiceResponse'] = _DEPLOYSERVICERESPONSE
DESCRIPTOR.message_types_by_name['MaybeBlockMessage'] = _MAYBEBLOCKMESSAGE
DESCRIPTOR.message_types_by_name['BlockQueryResponse'] = _BLOCKQUERYRESPONSE
DESCRIPTOR.message_types_by_name['ListeningNameDataResponse'] = _LISTENINGNAMEDATARESPONSE
DESCRIPTOR.message_types_by_name['ListeningNameContinuationResponse'] = _LISTENINGNAMECONTINUATIONRESPONSE
DESCRIPTOR.message_types_by_name['DataWithBlockInfo'] = _DATAWITHBLOCKINFO
DESCRIPTOR.message_types_by_name['ContinuationsWithBlockInfo'] = _CONTINUATIONSWITHBLOCKINFO
DESCRIPTOR.message_types_by_name['WaitingContinuationInfo'] = _WAITINGCONTINUATIONINFO
DESCRIPTOR.message_types_by_name['BlockInfoWithoutTuplespace'] = _BLOCKINFOWITHOUTTUPLESPACE
DESCRIPTOR.message_types_by_name['BlockInfo'] = _BLOCKINFO
DESCRIPTOR.message_types_by_name['ApprovedBlockCandidate'] = _APPROVEDBLOCKCANDIDATE
DESCRIPTOR.message_types_by_name['UnapprovedBlock'] = _UNAPPROVEDBLOCK
DESCRIPTOR.message_types_by_name['Signature'] = _SIGNATURE
DESCRIPTOR.message_types_by_name['BlockApproval'] = _BLOCKAPPROVAL
DESCRIPTOR.message_types_by_name['ApprovedBlock'] = _APPROVEDBLOCK
DESCRIPTOR.message_types_by_name['ApprovedBlockRequest'] = _APPROVEDBLOCKREQUEST
DESCRIPTOR.message_types_by_name['NoApprovedBlockAvailable'] = _NOAPPROVEDBLOCKAVAILABLE
DESCRIPTOR.message_types_by_name['BlockMessage'] = _BLOCKMESSAGE
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['ProcessedDeploy'] = _PROCESSEDDEPLOY
DESCRIPTOR.message_types_by_name['Body'] = _BODY
DESCRIPTOR.message_types_by_name['Justification'] = _JUSTIFICATION
DESCRIPTOR.message_types_by_name['RChainState'] = _RCHAINSTATE
DESCRIPTOR.message_types_by_name['Deploy'] = _DEPLOY
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['ProduceEvent'] = _PRODUCEEVENT
DESCRIPTOR.message_types_by_name['ConsumeEvent'] = _CONSUMEEVENT
DESCRIPTOR.message_types_by_name['CommEvent'] = _COMMEVENT
DESCRIPTOR.message_types_by_name['Bond'] = _BOND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PhloLimit = _reflection.GeneratedProtocolMessageType('PhloLimit', (_message.Message,), dict(
  DESCRIPTOR = _PHLOLIMIT,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.PhloLimit)
  ))
_sym_db.RegisterMessage(PhloLimit)

PhloPrice = _reflection.GeneratedProtocolMessageType('PhloPrice', (_message.Message,), dict(
  DESCRIPTOR = _PHLOPRICE,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.PhloPrice)
  ))
_sym_db.RegisterMessage(PhloPrice)

DeployData = _reflection.GeneratedProtocolMessageType('DeployData', (_message.Message,), dict(
  DESCRIPTOR = _DEPLOYDATA,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.DeployData)
  ))
_sym_db.RegisterMessage(DeployData)

BlockRequest = _reflection.GeneratedProtocolMessageType('BlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKREQUEST,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.BlockRequest)
  ))
_sym_db.RegisterMessage(BlockRequest)

BlockQuery = _reflection.GeneratedProtocolMessageType('BlockQuery', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKQUERY,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.BlockQuery)
  ))
_sym_db.RegisterMessage(BlockQuery)

BlocksQuery = _reflection.GeneratedProtocolMessageType('BlocksQuery', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKSQUERY,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.BlocksQuery)
  ))
_sym_db.RegisterMessage(BlocksQuery)

DataAtNameQuery = _reflection.GeneratedProtocolMessageType('DataAtNameQuery', (_message.Message,), dict(
  DESCRIPTOR = _DATAATNAMEQUERY,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.DataAtNameQuery)
  ))
_sym_db.RegisterMessage(DataAtNameQuery)

ContinuationAtNameQuery = _reflection.GeneratedProtocolMessageType('ContinuationAtNameQuery', (_message.Message,), dict(
  DESCRIPTOR = _CONTINUATIONATNAMEQUERY,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ContinuationAtNameQuery)
  ))
_sym_db.RegisterMessage(ContinuationAtNameQuery)

DeployServiceResponse = _reflection.GeneratedProtocolMessageType('DeployServiceResponse', (_message.Message,), dict(
  DESCRIPTOR = _DEPLOYSERVICERESPONSE,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.DeployServiceResponse)
  ))
_sym_db.RegisterMessage(DeployServiceResponse)

MaybeBlockMessage = _reflection.GeneratedProtocolMessageType('MaybeBlockMessage', (_message.Message,), dict(
  DESCRIPTOR = _MAYBEBLOCKMESSAGE,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.MaybeBlockMessage)
  ))
_sym_db.RegisterMessage(MaybeBlockMessage)

BlockQueryResponse = _reflection.GeneratedProtocolMessageType('BlockQueryResponse', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKQUERYRESPONSE,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.BlockQueryResponse)
  ))
_sym_db.RegisterMessage(BlockQueryResponse)

ListeningNameDataResponse = _reflection.GeneratedProtocolMessageType('ListeningNameDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTENINGNAMEDATARESPONSE,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ListeningNameDataResponse)
  ))
_sym_db.RegisterMessage(ListeningNameDataResponse)

ListeningNameContinuationResponse = _reflection.GeneratedProtocolMessageType('ListeningNameContinuationResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTENINGNAMECONTINUATIONRESPONSE,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ListeningNameContinuationResponse)
  ))
_sym_db.RegisterMessage(ListeningNameContinuationResponse)

DataWithBlockInfo = _reflection.GeneratedProtocolMessageType('DataWithBlockInfo', (_message.Message,), dict(
  DESCRIPTOR = _DATAWITHBLOCKINFO,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.DataWithBlockInfo)
  ))
_sym_db.RegisterMessage(DataWithBlockInfo)

ContinuationsWithBlockInfo = _reflection.GeneratedProtocolMessageType('ContinuationsWithBlockInfo', (_message.Message,), dict(
  DESCRIPTOR = _CONTINUATIONSWITHBLOCKINFO,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ContinuationsWithBlockInfo)
  ))
_sym_db.RegisterMessage(ContinuationsWithBlockInfo)

WaitingContinuationInfo = _reflection.GeneratedProtocolMessageType('WaitingContinuationInfo', (_message.Message,), dict(
  DESCRIPTOR = _WAITINGCONTINUATIONINFO,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.WaitingContinuationInfo)
  ))
_sym_db.RegisterMessage(WaitingContinuationInfo)

BlockInfoWithoutTuplespace = _reflection.GeneratedProtocolMessageType('BlockInfoWithoutTuplespace', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKINFOWITHOUTTUPLESPACE,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.BlockInfoWithoutTuplespace)
  ))
_sym_db.RegisterMessage(BlockInfoWithoutTuplespace)

BlockInfo = _reflection.GeneratedProtocolMessageType('BlockInfo', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKINFO,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.BlockInfo)
  ))
_sym_db.RegisterMessage(BlockInfo)

ApprovedBlockCandidate = _reflection.GeneratedProtocolMessageType('ApprovedBlockCandidate', (_message.Message,), dict(
  DESCRIPTOR = _APPROVEDBLOCKCANDIDATE,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ApprovedBlockCandidate)
  ))
_sym_db.RegisterMessage(ApprovedBlockCandidate)

UnapprovedBlock = _reflection.GeneratedProtocolMessageType('UnapprovedBlock', (_message.Message,), dict(
  DESCRIPTOR = _UNAPPROVEDBLOCK,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.UnapprovedBlock)
  ))
_sym_db.RegisterMessage(UnapprovedBlock)

Signature = _reflection.GeneratedProtocolMessageType('Signature', (_message.Message,), dict(
  DESCRIPTOR = _SIGNATURE,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.Signature)
  ))
_sym_db.RegisterMessage(Signature)

BlockApproval = _reflection.GeneratedProtocolMessageType('BlockApproval', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKAPPROVAL,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.BlockApproval)
  ))
_sym_db.RegisterMessage(BlockApproval)

ApprovedBlock = _reflection.GeneratedProtocolMessageType('ApprovedBlock', (_message.Message,), dict(
  DESCRIPTOR = _APPROVEDBLOCK,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ApprovedBlock)
  ))
_sym_db.RegisterMessage(ApprovedBlock)

ApprovedBlockRequest = _reflection.GeneratedProtocolMessageType('ApprovedBlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _APPROVEDBLOCKREQUEST,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ApprovedBlockRequest)
  ))
_sym_db.RegisterMessage(ApprovedBlockRequest)

NoApprovedBlockAvailable = _reflection.GeneratedProtocolMessageType('NoApprovedBlockAvailable', (_message.Message,), dict(
  DESCRIPTOR = _NOAPPROVEDBLOCKAVAILABLE,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.NoApprovedBlockAvailable)
  ))
_sym_db.RegisterMessage(NoApprovedBlockAvailable)

BlockMessage = _reflection.GeneratedProtocolMessageType('BlockMessage', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKMESSAGE,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.BlockMessage)
  ))
_sym_db.RegisterMessage(BlockMessage)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
  DESCRIPTOR = _HEADER,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.Header)
  ))
_sym_db.RegisterMessage(Header)

ProcessedDeploy = _reflection.GeneratedProtocolMessageType('ProcessedDeploy', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSEDDEPLOY,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ProcessedDeploy)
  ))
_sym_db.RegisterMessage(ProcessedDeploy)

Body = _reflection.GeneratedProtocolMessageType('Body', (_message.Message,), dict(
  DESCRIPTOR = _BODY,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.Body)
  ))
_sym_db.RegisterMessage(Body)

Justification = _reflection.GeneratedProtocolMessageType('Justification', (_message.Message,), dict(
  DESCRIPTOR = _JUSTIFICATION,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.Justification)
  ))
_sym_db.RegisterMessage(Justification)

RChainState = _reflection.GeneratedProtocolMessageType('RChainState', (_message.Message,), dict(
  DESCRIPTOR = _RCHAINSTATE,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.RChainState)
  ))
_sym_db.RegisterMessage(RChainState)

Deploy = _reflection.GeneratedProtocolMessageType('Deploy', (_message.Message,), dict(
  DESCRIPTOR = _DEPLOY,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.Deploy)
  ))
_sym_db.RegisterMessage(Deploy)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), dict(
  DESCRIPTOR = _EVENT,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.Event)
  ))
_sym_db.RegisterMessage(Event)

ProduceEvent = _reflection.GeneratedProtocolMessageType('ProduceEvent', (_message.Message,), dict(
  DESCRIPTOR = _PRODUCEEVENT,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ProduceEvent)
  ))
_sym_db.RegisterMessage(ProduceEvent)

ConsumeEvent = _reflection.GeneratedProtocolMessageType('ConsumeEvent', (_message.Message,), dict(
  DESCRIPTOR = _CONSUMEEVENT,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ConsumeEvent)
  ))
_sym_db.RegisterMessage(ConsumeEvent)

CommEvent = _reflection.GeneratedProtocolMessageType('CommEvent', (_message.Message,), dict(
  DESCRIPTOR = _COMMEVENT,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.CommEvent)
  ))
_sym_db.RegisterMessage(CommEvent)

Bond = _reflection.GeneratedProtocolMessageType('Bond', (_message.Message,), dict(
  DESCRIPTOR = _BOND,
  __module__ = 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.Bond)
  ))
_sym_db.RegisterMessage(Bond)


DESCRIPTOR._options = None

_DEPLOYSERVICE = _descriptor.ServiceDescriptor(
  name='DeployService',
  full_name='coop.rchain.casper.protocol.DeployService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=4343,
  serialized_end=5288,
  methods=[
  _descriptor.MethodDescriptor(
    name='DoDeploy',
    full_name='coop.rchain.casper.protocol.DeployService.DoDeploy',
    index=0,
    containing_service=None,
    input_type=_DEPLOYDATA,
    output_type=_DEPLOYSERVICERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='addBlock',
    full_name='coop.rchain.casper.protocol.DeployService.addBlock',
    index=1,
    containing_service=None,
    input_type=_BLOCKMESSAGE,
    output_type=_DEPLOYSERVICERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='createBlock',
    full_name='coop.rchain.casper.protocol.DeployService.createBlock',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_DEPLOYSERVICERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='showBlock',
    full_name='coop.rchain.casper.protocol.DeployService.showBlock',
    index=3,
    containing_service=None,
    input_type=_BLOCKQUERY,
    output_type=_BLOCKQUERYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='showMainChain',
    full_name='coop.rchain.casper.protocol.DeployService.showMainChain',
    index=4,
    containing_service=None,
    input_type=_BLOCKSQUERY,
    output_type=_BLOCKINFOWITHOUTTUPLESPACE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='showBlocks',
    full_name='coop.rchain.casper.protocol.DeployService.showBlocks',
    index=5,
    containing_service=None,
    input_type=_BLOCKSQUERY,
    output_type=_BLOCKINFOWITHOUTTUPLESPACE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='listenForDataAtName',
    full_name='coop.rchain.casper.protocol.DeployService.listenForDataAtName',
    index=6,
    containing_service=None,
    input_type=_DATAATNAMEQUERY,
    output_type=_LISTENINGNAMEDATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='listenForContinuationAtName',
    full_name='coop.rchain.casper.protocol.DeployService.listenForContinuationAtName',
    index=7,
    containing_service=None,
    input_type=_CONTINUATIONATNAMEQUERY,
    output_type=_LISTENINGNAMECONTINUATIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEPLOYSERVICE)

DESCRIPTOR.services_by_name['DeployService'] = _DEPLOYSERVICE

# @@protoc_insertion_point(module_scope)



# NOTE: this hack is needed because protc uses absolute imports...
import os
import sys

ROOT = os.path.dirname(__file__)
GENERATED = os.path.join(ROOT, 'generated')
sys.path.append(GENERATED)

import CasperMessage_pb2  # isort:skip
import CasperMessage_pb2_grpc  # isort:skip
import RhoTypes_pb2  # isort:skip
import RhoTypes_pb2_grpc  # isort:skip

__version__ = '0.7.0'
